import javax.jdo.*;
import javax.jdo.identity.StringIdentity;
import java.util.Properties;
public class Test{
    private static PersistenceManager persistenceManager;
    public static void main(String[] args) throws Exception{
        System.out.format("Running Test ...%n");
        openDatabase();
        System.out.format("ignoreCache is %b.%n", persistenceManager.getIgnoreCache());

        // Comment out the line below, when above line correctly returns "ignoreCache is false", to finish testing
        // Extent respecting cache.
        if(persistenceManager.getIgnoreCache())persistenceManager.setIgnoreCache(false);

        if(persistenceManager.getIgnoreCache()) throw new Exception("ignoreCache should be FALSE.");
        Transaction transaction = persistenceManager.currentTransaction();
        try{
            transaction.begin();
            Data data = new Data();
            data.setId(new StringIdentity(Data.class, "Object1"));
            data.setStringData("My data for Object1.");
            persistenceManager.makePersistent(data);
            data = new Data();
            data.setId(new StringIdentity(Data.class, "Object2"));
            data.setStringData("My data for Object2.");
            persistenceManager.makePersistent(data);
            listObjects();
            persistenceManager.deletePersistent(data);
            listObjects();
            transaction.commit();
        }finally{
            if(transaction.isActive()) transaction.rollback();
        }
        System.out.format("Test complete.%n");
    }
    private static void openDatabase(){
        Properties properties = new Properties();
        properties.setProperty("javax.jdo.PersistenceManagerFactoryClass", "com.objectdb.jdo.PMF");
        properties.setProperty("javax.jdo.option.Optimistic", "true");
        properties.setProperty("javax.jdo.option.RetainValues", "true");
        properties.setProperty("javax.jdo.option.RestoreValues", "false");
        properties.setProperty("javax.jdo.option.IgnoreCache", "false");
        properties.setProperty("javax.jdo.option.NontransactionalRead", "false");
        properties.setProperty("javax.jdo.option.NontransactionalWrite", "false");
        properties.setProperty("javax.jdo.option.Multithreaded", "true");
        properties.setProperty("javax.jdo.option.DetachAllOnCommit", "false");
        properties.setProperty("javax.jdo.option.CopyOnAttach", "false");
        properties.setProperty("javax.jdo.option.TransactionType", "RESOURCE_LOCAL");
        properties.setProperty("javax.jdo.option.TransactionIsolationLevel", "read-uncommitted");
        properties.setProperty("javax.jdo.option.ConnectionURL", "Test.tmp;drop");
        PersistenceManagerFactory persistenceManagerFactory = JDOHelper.getPersistenceManagerFactory(properties);
        persistenceManager = persistenceManagerFactory.getPersistenceManager();
    }
    private static void listObjects() throws Exception{
        Extent<Data> dataExtent = persistenceManager.getExtent(Data.class, false);
        persistenceManager.retrieveAll(dataExtent);
        System.out.format("Listing objects:%n");
        try{
            for(Data data : dataExtent){
                System.out.format("%s, %s%n", data.getId(), data.getStringData());
            }
        }
        finally{
            dataExtent.closeAll();
        }
    }
}
